def error_response(status:str, message:str):
    """
    Custom error response

    Args:
        status ([string]): [status message -> 404 not found, 500 server error, 400 bad request, etc]
        message ([string]): [what error message do you want to show to the end user?]

    Returns:
        [response]: [Returns a dictionary of status, and message]
    """
    
    payload = {
        "status": status,
        "message": message
    }
    return payload


def success_response(status:str, message:str, data:dict):
    """
    Custom success response

    Args:
        status ([string]): [status message -> 201 created, 200 ok, 202 accepted, etc]
        message ([string]): [what message do you want to show to the end user?]
        data ([dict]): [serialized data from the server side]

    Returns:
        [response]: [Returns a dictionary of status, message, data of whatever object that was serialized]
    """
    
    payload = {
        "status": status,
        "message": message,
        "data": data
    }
    return payload



from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Intended Audience :: Developers',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='rest_api_payload',
  version='0.0.4',
  description='Industry ready custom API payload with an easy format for building Python APIs (Django/Django Rest Framework)',
  long_description_content_type="text/markdown",
  long_description=open('README.md').read(),
  url='https://github.com/israelabraham/API-Payload',  
  author='Abram 🐼',
  author_email='israelvictory87@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords=['api', 'payload', 'custom api payload'], 
  packages=find_packages(),
  install_requires=[''] 
)